@@ -1,5 +1,4 @@
-### R code from vignette source 'crisk'
-### Encoding: UTF-8
+### R code from vignette source 'crisk.rnw'
 
 ###################################################
 ### code chunk number 1: crisk.rnw:25-28
@@ -40,6 +39,7 @@ summary(Sdm)
 ###################################################
 ### code chunk number 4: boxes5
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes(Mdm, boxpos = list(x = c(15, 50, 15, 85, 85),
                          y = c(85, 50, 15, 85, 15)), 
           scale.R = 100, 
@@ -49,6 +49,7 @@ boxes(Mdm, boxpos = list(x = c(15, 50, 15, 85, 85),
 ###################################################
 ### code chunk number 5: boxes4
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes(Relevel(Sdm, c(1, 4, 2, 3)), 
       boxpos  = list(x = c(15, 85, 80, 15),
                      y = c(85, 85, 20, 15)),
@@ -76,6 +77,7 @@ str(nd)
 ###################################################
 ### code chunk number 8: rates
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 matshade(nd$tfd, cbind(ci.pred(mD, nd),
                        ci.pred(mI, nd),
                        ci.pred(mO, nd))*1000, 
@@ -130,6 +132,7 @@ options(oo)
 ###################################################
 ### code chunk number 11: stack
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 zz <- mat2pol(cbind(rD, rI, rO, Sv), x = nd$tfd, 
               xlim = c(0,10), xaxs = "i", yaxs = "i", las = 1,
               xlab = "Time since DM diagnosis (years)", 
@@ -211,6 +214,7 @@ str(Brates)
 ###################################################
 ### code chunk number 19: rates-ci
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 matshade(nd$tfd, cbind(ci.pred(mD, nd),
                        ci.pred(mI, nd),
                        ci.pred(mO, nd))*1000, 
@@ -235,6 +239,7 @@ text(0, 0.5*0.6^c(1,2,0),
 ###################################################
 ### code chunk number 20: crates
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 matshade(res$time,
          cbind(res$Crisk[,"Dead",],
                res$Crisk[,"Ins" ,],
@@ -258,6 +263,7 @@ str(res$Srisk)
 ###################################################
 ### code chunk number 22: stack-ci
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 zz <- mat2pol(res$Crisk[,c("Dead","Ins","OAD","Surv"),1],
               x = res$time,
            xlim = c(0,10), xaxs = "i", yaxs = "i", las = 1,
@@ -328,6 +334,7 @@ summary(dmL, t = T)
 ###################################################
 ### code chunk number 30: boxes
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes(dmL, boxpos = TRUE)
 
 
@@ -373,6 +380,7 @@ str(cR)
 ###################################################
 ### code chunk number 36: cR
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 clr <- c("black","orange","limegreen")
 matshade(cR$time, cbind(cR$Crisk[, "CVD"  ,],
                         cR$Crisk[, "Can"  ,],
@@ -386,6 +394,7 @@ text(0, 1/3 - 1:3/30, c("CVD","Can","Oth"),
 ###################################################
 ### code chunk number 37: Sr1
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 matshade(cR$time, cbind(cR$Srisk[,1,],
                         cR$Srisk[,2,],
                         cR$Srisk[,3,]),
@@ -399,6 +408,7 @@ box()
 ###################################################
 ### code chunk number 38: Sr2
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 zz <- mat2pol(cR$Crisk[,c("Other","Can","CVD","Surv"),"50%"], 
               x = cR$time, 
            xlim = c(0,15), xaxs = "i", yaxs = "i", las = 1,
