@@ -1,5 +1,4 @@
-### R code from vignette source 'flup'
-### Encoding: UTF-8
+### R code from vignette source 'flup.rnw'
 
 ###################################################
 ### code chunk number 1: flup.rnw:22-27
@@ -48,12 +47,14 @@ summary.Lexis( dmL, timeScales=TRUE )
 ###################################################
 ### code chunk number 6: dmL1
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 plot( dmL )
 
 
 ###################################################
 ### code chunk number 7: dmL2
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 par(mar=c(3,3,1,1), mgp=c(3,1,0)/1.6 )
 plot(dmL, 1:2, lwd=1, col=c("blue","red")[dmL$sex],
      grid=TRUE, lty.grid=1, col.grid=gray(0.7),
@@ -146,6 +147,7 @@ summary(dmS2C, timeScales = TRUE)
 ###################################################
 ### code chunk number 16: box1
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes(dmC, boxpos = TRUE, scale.R = 1000, show.BE = TRUE)
 
 
@@ -238,6 +240,7 @@ c( deviance(ma), deviance(Ma), deviance(Xa), deviance(xa) )
 ###################################################
 ### code chunk number 28: pr-a
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 nd <- data.frame( age=40:85, lex.dur=1000 )
 pr.0 <- ci.pred( ma, newdata = nd )      # mortality per 100 PY
 pr.a <- ci.pred( Ma, newdata = nd )*1000 # mortality per 100 PY
@@ -286,6 +289,7 @@ round( ci.exp( Pm, subset="ex" ), 3 )
 ###################################################
 ### code chunk number 33: ins-time
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 ndI <- data.frame( expand.grid( tfI=c(NA,seq(0,15,0.1)),
                                 ai=seq(40,80,10) ),
                    sex="M",
@@ -329,6 +333,7 @@ round( cbind( ci.exp( Pm ),
 ###################################################
 ### code chunk number 37: Ieff
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 nd <- data.frame( tfI=seq(0,15,,151), lex.Cst="Ins", sex="M" )
 nr <- data.frame( tfI=    2         , lex.Cst="Ins", sex="M" )
 ppr <- ci.exp( pm, list(nd,nr), xvars="age" )
@@ -343,6 +348,7 @@ abline( h=1, lty=3 )
 ###################################################
 ### code chunk number 38: IeffR
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 nd <- data.frame( tfI=seq(0,15,,151), lex.Cst="Ins", sex="M" )
 nr <- data.frame( tfI=    0         , lex.Cst="DM" , sex="M" )
 ppr <- ci.exp( pm, list(nd,nr), xvars="age" )
@@ -388,6 +394,7 @@ anova( imx, Im, im, test='Chisq')
 ###################################################
 ### code chunk number 42: dur-int
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 pxi <- ci.pred( imx, ndI )
 pxa <- ci.pred( imx, ndA )
 pIi <- ci.pred( Im , ndI )
@@ -405,6 +412,7 @@ matshade( ndA$age, cbind( pxa, pIa, pia)*1000,
 ###################################################
 ### code chunk number 43: dur-int-RR
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 ndR <- transform( ndI, tfI=0, lex.Cst="DM" )
 cbind( head(ndI), head(ndR) )
 Rxi <- ci.exp( imx, list(ndI,ndR) )
@@ -421,6 +429,7 @@ abline( h=ci.exp(imx,subset="lex.Cst")[,1], lty="25", col="blue" )
 ###################################################
 ### code chunk number 44: splint
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 gm <- glm.Lexis( tsNA20(dmCs), 
                  formula = ~ Ns(age,knots=a.kn) 
                            + Ns(tfI,knots=i.kn)
@@ -441,6 +450,7 @@ matshade( ndA$age, cbind( pga, pia )*1000,
 ###################################################
 ### code chunk number 45: RR-int
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 ndR <- transform( ndI, lex.Cst="DM", tfI=0 )
 iRR <- ci.exp( im, ctr.mat=list(ndI,ndR) )
 gRR <- ci.exp( gm, ctr.mat=list(ndI,ndR) )
@@ -472,6 +482,7 @@ dma <- ci.pred( dmd, ndA )
 ###################################################
 ### code chunk number 47: sep-mort
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 par(mar=c(3,3,1,1),mgp=c(3,1,0)/1.6,las=1,bty="n")
 matshade( ndI$age, ini*1000, plot=TRUE, log="y",
           xlab="Age (years)", ylab="Mortality rates per 1000 PY",
@@ -483,6 +494,7 @@ matshade( ndA$age, dma*1000,
 ###################################################
 ### code chunk number 48: sep-HR
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 par(mar=c(3,3,1,1),mgp=c(3,1,0)/1.6,las=1,bty="n")
 matshade( ndI$age, ci.ratio(ini,dmi), plot=TRUE, log="y",
           xlab="Age (years)", ylab="RR insulin vs. no insulin",
@@ -506,6 +518,7 @@ summary( dmCs )
 ###################################################
 ### code chunk number 50: box4
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes( dmCs, boxpos=list(x=c(15,15,85,85),
                          y=c(85,15,85,15)),
        scale.R=1000, show.BE=TRUE )
@@ -536,6 +549,7 @@ subset(dmM, lex.id %in% wh)
 ###################################################
 ### code chunk number 53: mbox
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 boxes( dmM, boxpos=list(x=c(15,80,40,40,85,85),
                         y=c(50,50,90,10,90,10)),
             scale.R=1000, show.BE=TRUE )
@@ -544,6 +558,7 @@ boxes( dmM, boxpos=list(x=c(15,80,40,40,85,85),
 ###################################################
 ### code chunk number 54: mboxr
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 summary( dmMr <- Relevel( dmM, list('OAD+Ins'=5:6), first=FALSE) )
 boxes( dmMr, boxpos=list(x=c(15,50,15,85,85),
                          y=c(85,50,15,85,15)),
